# Grand Unified SAS Runner 

We have enough of these around that we ought to just build out one robust implementation and `import` it within projects as needed.

This is currently in alpha -- please feel free to contribute. It's basically an MVP as is.

## Tests

Run tests with `python -m unittest testsas`
